Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(177)

Unified Diff: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestCcCanMakePaymentQueryNoCardTest.java

Issue 2545523004: Rename canMakeActivePayment to canMakePayment (Closed)
Patch Set: Rebase Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestCcCanMakePaymentQueryNoCardTest.java
diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestCcActivePaymentQueryNoCardTest.java b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestCcCanMakePaymentQueryNoCardTest.java
similarity index 72%
rename from chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestCcActivePaymentQueryNoCardTest.java
rename to chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestCcCanMakePaymentQueryNoCardTest.java
index 02b5cce503ec0229c5c401ca26be2f5258ff0973..dc4de1478afd10a3a7b44afba3d30f574b7060b6 100644
--- a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestCcActivePaymentQueryNoCardTest.java
+++ b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestCcCanMakePaymentQueryNoCardTest.java
@@ -16,20 +16,20 @@ import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeoutException;
/**
- * A payment integration test for checking whether user can make active payment via a credit card.
+ * A payment integration test for checking whether user can make a payment via a credit card.
* This user does not have a complete credit card on file.
*/
-@CommandLineFlags.Add("enable-blink-features=CanMakeActivePayment")
-public class PaymentRequestCcActivePaymentQueryNoCardTest extends PaymentRequestTestBase {
- public PaymentRequestCcActivePaymentQueryNoCardTest() {
- super("payment_request_active_payment_query_cc_test.html");
+@CommandLineFlags.Add("enable-blink-features=CanMakePayment")
+public class PaymentRequestCcCanMakePaymentQueryNoCardTest extends PaymentRequestTestBase {
+ public PaymentRequestCcCanMakePaymentQueryNoCardTest() {
+ super("payment_request_can_make_payment_query_cc_test.html");
}
@Override
public void onMainActivityStarted() throws InterruptedException, ExecutionException,
TimeoutException {
// The user has an incomplete credit card on file. This is not sufficient for
// canMakeActivePayment() to return true.
new AutofillTestHelper().setCreditCard(new CreditCard("", "https://example.com", true, true,
"Jon Doe", "4111111111111111", "1111", "12", "2050", "visa", R.drawable.pr_visa,
"" /* billingAddressId */, "" /* serverId */));
@@ -37,9 +37,9 @@ public class PaymentRequestCcActivePaymentQueryNoCardTest extends PaymentRequest
@MediumTest
@Feature({"Payments"})
- public void testCannotMakeActivePayment() throws InterruptedException, ExecutionException,
+ public void testCannotMakePayment() throws InterruptedException, ExecutionException,
TimeoutException {
- openPageAndClickBuyAndWait(mActivePaymentQueryResponded);
+ openPageAndClickBuyAndWait(mCanMakePaymentQueryResponded);
expectResultContains(new String[]{"false"});
}
}
@@ -16,20 +16,20 @@ import java.util.concurrent.ExecutionException;
TimeoutException {
// The user has an incomplete credit card on file. This is not sufficient for
- // canMakeActivePayment() to return true.
+ // canMakePayment() to return true.
new AutofillTestHelper().setCreditCard(new CreditCard("", "https://example.com", true, true,
"Jon Doe", "4111111111111111", "1111", "12", "2050", "visa", R.drawable.pr_visa,

Powered by Google App Engine
This is Rietveld 408576698